[CalendarServer-changes] [9451] CalendarServer/branches/users/gaya/inviteclean/txdav/common/ iinvitation.py

source_changes at macosforge.org source_changes at macosforge.org
Fri Jul 13 15:25:27 PDT 2012


Revision: 9451
          http://trac.macosforge.org/projects/calendarserver/changeset/9451
Author:   gaya at apple.com
Date:     2012-07-13 15:25:27 -0700 (Fri, 13 Jul 2012)
Log Message:
-----------
IInvitate -> IInvitation

Modified Paths:
--------------
    CalendarServer/branches/users/gaya/inviteclean/txdav/common/iinvitation.py

Modified: CalendarServer/branches/users/gaya/inviteclean/txdav/common/iinvitation.py
===================================================================
--- CalendarServer/branches/users/gaya/inviteclean/txdav/common/iinvitation.py	2012-07-13 22:23:19 UTC (rev 9450)
+++ CalendarServer/branches/users/gaya/inviteclean/txdav/common/iinvitation.py	2012-07-13 22:25:27 UTC (rev 9451)
@@ -22,12 +22,12 @@
 
 
 __all__ = [
-    "IInvite",
+    "IInvitation",
 ]
 
-class IInvite(Interface):
+class IInvitation(Interface):
     """
     IInvite.  The state of the an invitation to a shared resource.
     
     """
   
@@ -65,7 +65,7 @@
 
 def state():
     """
-    Invite or bind state.  Currently, one of "NEEDS-ACTION","ACCEPTED", "DECLINED", "INVALID".
+    Invitation or bind state.  Currently, one of "NEEDS-ACTION","ACCEPTED", "DECLINED", "INVALID".
 
     @return: the invitation state
     @rtype: C{str}
-------------- next part --------------
@@ -22,12 +22,12 @@
     """
-    IInvite.  The state of the an invitation to a shared resource.
+    IInvitation.  The state of the an invitation to a shared resource.
     
     """
An HTML attachment was scrubbed...
URL: <http://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20120713/cc811ed2/attachment-0001.html>


More information about the calendarserver-changes mailing list